@@ -2,12 +2,11 @@
 This is a URLconf to be loaded by tests.py. Add any URLs needed for tests only.
 """
 
-from django.conf.urls import url
+from django.urls import path
 
-from .tests import TestFormPreview
 from .forms import TestForm
-
+from .tests import TestFormPreview
 
 urlpatterns = [
-    url(r'^preview/', TestFormPreview(TestForm)),
+    path('preview/', TestFormPreview(TestForm)),
 ]
